@@ -1,7 +1,7 @@
 package TestAppLoader;
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use DBI;
 use File::Temp;
